NextTuple

Trait NextTuple 

pub trait NextTuple {
    type Output<Next>;

    // Required method
    fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>;
}
Allows extending a tuple, or creating a new tuple, by adding the next value.

Required Associated Types

type Output<Next>

The type that will be returned by adding another value of type Next to the end of the current type.

Required Methods

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Adds the next value and returns the result.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl NextTuple for ()

Source

type Output<Next> = (Next,)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A> NextTuple for (A,)

Source

type Output<Next> = (A, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B> NextTuple for (A, B)

Source

type Output<Next> = (A, B, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C> NextTuple for (A, B, C)

Source

type Output<Next> = (A, B, C, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D> NextTuple for (A, B, C, D)

Source

type Output<Next> = (A, B, C, D, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E> NextTuple for (A, B, C, D, E)

Source

type Output<Next> = (A, B, C, D, E, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F> NextTuple for (A, B, C, D, E, F)

Source

type Output<Next> = (A, B, C, D, E, F, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F, G> NextTuple for (A, B, C, D, E, F, G)

Source

type Output<Next> = (A, B, C, D, E, F, G, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F, G, H> NextTuple for (A, B, C, D, E, F, G, H)

Source

type Output<Next> = (A, B, C, D, E, F, G, H, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F, G, H, I> NextTuple for (A, B, C, D, E, F, G, H, I)

Source

type Output<Next> = (A, B, C, D, E, F, G, H, I, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F, G, H, I, J> NextTuple for (A, B, C, D, E, F, G, H, I, J)

Source

type Output<Next> = (A, B, C, D, E, F, G, H, I, J, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F, G, H, I, J, K> NextTuple for (A, B, C, D, E, F, G, H, I, J, K)

Source

type Output<Next> = (A, B, C, D, E, F, G, H, I, J, K, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

type Output<Next> = (A, B, C, D, E, F, G, H, I, J, K, L, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M)

Source

type Output<Next> = (A, B, C, D, E, F, G, H, I, J, K, L, M, Next)

Source

fn next_tuple<Next>(self, next: Next) -> Self::Output<Next>

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y)

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z> NextTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z)

Implementors